@@ -5,6 +5,7 @@ import json
 import sys
 from datetime import date, datetime, time
 from pathlib import Path
+from typing import Union
 from uuid import uuid4
 
 import requests
@@ -19,7 +20,12 @@ from jsonutils.exceptions import (
     JSONQueryException,
     JSONQueryMultipleValues,
 )
-from jsonutils.functions.decorators import catch_exceptions, dummy, return_value_on_exception
+from jsonutils.functions.decorators import (
+    catch_exceptions,
+    dummy,
+    global_config,
+    return_value_on_exception,
+)
 from jsonutils.functions.external import (
     DjangoQuerySet,
     NumpyArray,
@@ -155,15 +161,17 @@ class JSONObject:
         "_is_annotation",
     )
 
-    def __new__(cls, data=None, raise_exception=False, serialize_nodes=False):
+    def __new__(
+        cls, data=None, raise_exception=False, serialize_nodes=False
+    ) -> Union["JSONDict", "JSONList", "JSONStr", "JSONInt", "JSONFloat", "JSONNull", "JSONBool"]:
         """
-        Params:
+        Params
         ------
-            data: the json data that is going to be parsed.
-            raise_exception: if True, then an exception will be raised if data type is not known. Otherwise, a JSONUnknown
-                instance will be created for such a data.
-            serialize_nodes: if True and data represents a node instance, then take it as a raw data, discarding
-                all its old node attributes (like jsonpath, parent, etc).
+        - `data`: the json data that is going to be parsed.
+        - `raise_exception`: if True, then an exception will be raised if data type is not known. Otherwise, a JSONUnknown
+        instance will be created for such a data.
+        - `serialize_nodes`: if True and data represents a node instance, then take it as a raw data, discarding
+        all its old node attributes (like jsonpath, parent, etc).
         """
         if not isinstance(raise_exception, bool):
             raise TypeError(
@@ -206,7 +214,7 @@ class JSONObject:
                 raise JSONDecodeException(f"Wrong data's format: {type(data)}")
 
     @classmethod
-    def open(cls, file, raise_exception=True, **kwargs):
+    def open(cls, file: str, raise_exception: bool = True, **kwargs):
         """
         Open an external JSON file.
         If a valid url string is passed, then it will try to make a get/post request to such a target and decode a json file
@@ -433,7 +441,7 @@ class JSONNode:
         is_callable = callable(new_obj)
 
         path = self.jsonpath
-        root = self.root
+        root: JSONDict = self.root
 
         if is_callable:
             try:
@@ -669,6 +677,13 @@ class JSONCompose(JSONNode):
             for index, item in enumerate(self):
                 self.__setitem__(index, item)
 
+    @global_config(native_types=False)
+    def copy(self):
+        current_path = self.jsonpath.keys
+        root_obj = JSONObject(self.root, serialize_nodes=True)
+        obj = root_obj.eval_path(current_path)
+        return obj
+
     def path_exists(self, iterable):
         """
         Returns a boolean especifing if selected path exist in the composed object.
@@ -1187,6 +1202,9 @@ class JSONSingleton(JSONNode):
             return
         return JSONNull(None)
 
+    def copy(self):
+        return self
+
 
 # ---- COMPOSE OBJECTS ----
 class JSONDict(dict, JSONCompose):
@@ -1196,6 +1214,7 @@ class JSONDict(dict, JSONCompose):
     get = JSONCompose.get  # override get method
     _get = dict.get  # original get method
     values = JSONNode.values
+    copy = JSONCompose.copy
 
     def __init__(self, *args, **kwargs):
 
@@ -1274,11 +1293,6 @@ class JSONDict(dict, JSONCompose):
         else:
             return self.__setitem__(name, value)
 
-    def copy(self):
-        cls = self.__class__
-        obj = cls(self.json_decode)
-        return obj
-
     def get_fields(self, *args, inplace=False):
         """
         Returns a subset of this dict with selected fields, if it exists
@@ -1380,6 +1394,8 @@ class JSONDict(dict, JSONCompose):
 class JSONList(list, JSONCompose):
     """A list object"""
 
+    copy = JSONCompose.copy
+
     def __init__(self, *args, **kwargs):
 
         super().__init__(*args, **kwargs)
@@ -1394,11 +1410,6 @@ class JSONList(list, JSONCompose):
         self._child_objects[child._id] = child
         return super().append(child)
 
-    def copy(self):
-        cls = self.__class__
-        obj = cls(self.json_decode)
-        return obj
-
     def length(self):
         return self.__len__()
 
